//
//  Constants.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 5/14/20.
//  Copyright © 2020 mSignia. All rights reserved.
//

import Foundation

struct GlobalConstants {
    struct JsonKeys {}
}

typealias JsonKeys = GlobalConstants.JsonKeys
extension GlobalConstants.JsonKeys {
    
    static let payloadKey = "payload"
    
    static let addressKey = "addresses"
    struct Address {
        
        static let fullName = "fullName"
        static let addressLine1 = "addressLine1"
        static let addressLine2 = "addressLine2"
        static let city = "city"
        static let state = "state"
        static let phone = "phone"
        static let countryCode = "cc"
        static let country = "country"
        static let zip = "zipCode"
        static let type = "type"
        static let defaultKey = "isDefault"
    }
    
    struct App {
     
        static let authToken = "3ds_demo_store_auth_token"
        static let userID = "3ds_demo_store_user_id"
        static let userEmail = "3ds_demo_store_user_email"
        static let userPassword = "3ds_demo_store_user_password"
    }
    
    struct AuthRequest {
        
        static let email = "email"
        static let type = "type"
        static let sdkAppID = "sdkAppID"
        static let sdkTransID = "sdkTransID"
        static let encryptionScheme = "encryptionScheme"
        static let sdkEncData = "sdkEncData"
        static let sdkEphemPubKey = "sdkEphemPubKey"
        static let addNewCard = "addNewCard"
        static let sdkReferenceNumber = "sdkReferenceNumber"
        static let deviceRenderOptions = "deviceRenderOptions"
        static let acctNumber = "acctNumber"
        static let acctType = "acctType"
        static let addrMatch = "addrMatch"
        static let homePhone = "homePhone"
        static let merchantName = "merchantName"
        static let threeDSRequestorAuthenticationInd = "threeDSRequestorAuthenticationInd"
        static let mobilePhone = "mobilePhone"
        static let workPhone = "workPhone"
        static let purchaseAmount = "purchaseAmount"
        static let purchaseCurrency = "purchaseCurrency"
        static let purchaseDate = "purchaseDate"
        static let purchaseExponent = "purchaseExponent"
        static let messageExtension = "messageExtension"
        static let threeDSRequestorPriorAuthenticationInfo = "threeDSRequestorPriorAuthenticationInfo"
        static let threeDSDemoRenderingType = "threeDSDemoRenderingType"
        static let threeDSDemoScenario = "threeDSDemoScenario"
        static let billAddrCity = "billAddrCity"
        static let billAddrCountry = "billAddrCountry"
        static let billAddrLine1 = "billAddrLine1"
        static let billAddrLine2 = "billAddrLine2"
        static let billAddrPostCode = "billAddrPostCode"
        static let billAddrState = "billAddrState"
        static let cardExpiryDate = "cardExpiryDate"
        static let cardholderName = "cardholderName"
        static let shipAddrCity = "shipAddrCity"
        static let sdkMaxTimeout = "sdkMaxTimeout"
        static let shipAddrCountry = "shipAddrCountry"
        static let shipAddrLine1 = "shipAddrLine1"
        static let shipAddrLine2 = "shipAddrLine2"
        static let shipAddrPostCode = "shipAddrPostCode"
        static let shipAddrState = "shipAddrState"
        static let demoCouponCode = "demoCouponCode"
        static let threeDSServerTransID = "threeDSServerTransID"
        static let acsSignedContent = "acsSignedContent"
        static let acsRefNumber = "acsReferenceNumber"
        static let acsTransID = "acsTransID"
        static let transStatus = "transStatus"
        static let messageCategory = "messageCategory"
        static let threeDSRequestorNPAInd = "threeDSRequestorNPAInd"
        static let directoryServerID = "directoryServerID"
    }
    
    struct AuthenticationResponse {
        
        static let errorCode = "errorCode"
        static let sdkTransID = "sdkTransID"
    }
    
    static let cardKey = "cards"
    struct Card {
        
        static let name = "name"
        static let cardNumber = "cardNumber"
        static let cvv = "cvv"
        static let type = "type"
        static let image = "imageUrl"
        static let expirationMonth = "expirationMonth"
        static let expirationYear = "expirationYear"
        static let isDefault = "isDefault"
        static let description = "description"
        static let cardID = "cardId"
        static let duplicate = "duplicate"
    }
    
    struct CardCompany {
        
        static let imageUrl = "imageUrl"
        static let name = "name"
    }
    
    struct Error {
        
        static let errorCode = "errorCode"
        static let errorMessage = "errorMessage"
        static let status = "status"
    }
    
    struct Login {
        
        static let email = "email"
        static let password = "password"
        static let token = "token"
        static let user = "user"
        static let expiration = "expiration"
    }
    
    struct Product {
        
        static let id = "id"
        static let name = "name"
        static let price = "price"
        static let imageUrl = "imageUrl"
        static let salePrice = "salePrice"
        static let salePercentage = "salePercentage"
    }
    
    struct ResponseObject {
        
        static let payload = "payload"
        static let products = "products"
        static let content = "content"
        static let cardCompanies = "cardCompanies"
    }
    
    struct SubscriptionRequest {
        
        static let threeDSServerTransID = "threeDSServerTransID"
        static let lineItems = "lineItems"
        static let acctNumber = "acctNumber"
        
        struct LineItem {
            
            static let quantity = "quantity"
            static let paymentAmount = "paymentAmount"
            static let paymentCount = "paymentCount"
        }
    }
    
    static let userKey = "user"
    struct User {
        
        static let id = "id"
        static let email = "email"
        static let addresses = "addresses"
        static let cards = "cards"
        static let password = "password"
        static let confirmPassword = "confirmPassword"
        static let defaultCardType = "defaultCardType"
    }
    
    struct Verification {
        
        struct Response {
            
            static let success = "success"
        }
    }
}
