//
//  ARes.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 5/14/20.
//  Copyright © 2020 mSignia. All rights reserved.
//

import Foundation

protocol ResponseIdentifying {
    var threeDSServerTransID: String? { get set }
    var sdkTransID: String? { get set }
    var idToDisplay: String { get }
}

enum TransactionStatus: String, Decodable {
    
    // MARK: - Cases
    case accept = "Y"
    case deny = "N"
    case challenge = "C"
    case attempted = "A"
    case notPerformed = "U"
    case decoupledAuthentication = "D"
    case informationOnly = "I"
}

class AuthenticationResponse: Decodable, ResponseIdentifying {
    
    // MARK: - Properties
    var acsTransID: String?
    var dsTransID: String?
    var eci: String?
    var threeDSServerTransID: String?
    var messageVersion: String?
    var acsChallengeMandated: String?
    var transStatus: TransactionStatus?
    var acsOperatorID: String?
    var dsReferenceNumber: String?
    var acsReferenceNumber: String?
    var authenticationValue: String?
    var messageType: String?
    var sdkTransID: String?
    var acsSignedContent: String?
//    var messageExtension: [[String: Any]]?
    var idToDisplay: String {
        return threeDSServerTransID ?? sdkTransID ?? "No 3DS Server Trans ID available"
    }
    
    // MARK: - Inits
    init(acsTransID: String?, dsTransID: String?, eci: String?, threeDSServerTransID: String?, messageVersion: String?, acsChallengeMandated: String?, transStatus: TransactionStatus?, acsOperatorID: String?, dsReferenceNumber: String?, acsReferenceNumber: String?, authenticationValue: String?, messageType: String?, sdkTransID: String?, acsSignedContent: String?) {
        self.acsTransID = acsTransID
        self.dsTransID = dsTransID
        self.eci = eci
        self.threeDSServerTransID = threeDSServerTransID
        self.messageVersion = messageVersion
        self.acsChallengeMandated = acsChallengeMandated
        self.transStatus = transStatus
        self.acsOperatorID = acsOperatorID
        self.dsReferenceNumber = dsReferenceNumber
        self.acsReferenceNumber = acsReferenceNumber
        self.authenticationValue = authenticationValue
        self.messageType = messageType
        self.sdkTransID = sdkTransID
        self.acsSignedContent = acsSignedContent
//        self.messageExtension = messageExtension
    }
}
