//
//  ErroResponse.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 5/14/20.
//  Copyright © 2020 mSignia. All rights reserved.
//

import Foundation

class ErroResponse: Decodable, ResponseIdentifying {
    
    // MARK: - Properties
    var threeDSServerTransID: String?
    var sdkTransID: String?
    var code: String
    var description: String
    var detail: String
    var messageVersion: String?
    var component: String?
    var errorMessageType: String?
    var messageType: String?
    var idToDisplay: String {
        return threeDSServerTransID ?? sdkTransID ?? "3DS Server Trans ID Not Availble"
    }
    
    // MARK: Inits
    init(threeDSServerTransID: String? = nil, sdkTransID: String? = nil, code: String = "", description: String = "", detail: String = "", messageVersion: String? = nil, component: String? = nil, errorMessageType: String? = nil, messageType: String? = nil) {
        self.threeDSServerTransID = threeDSServerTransID
        self.sdkTransID = sdkTransID
        self.code = code
        self.description = description
        self.detail = detail
        self.messageVersion = messageVersion
        self.component = component
        self.errorMessageType = errorMessageType
        self.messageType = messageType
    }
    
    // MARK: - Coding Keys
    private enum CodingKeys: String, CodingKey {
        case threeDSServerTransID
        case sdkTransID
        case code = "errorCode"
        case description = "errorDescription"
        case detail = "errorDetail"
        case messageVersion
        case component = "errorComponent"
        case errorMessageType
        case messageType
    }
    
    // MARK: - Printable
    func printAsString() -> String {
        var stringToReturn = ""
        let mirror = Mirror(reflecting: self)
        for (name, value) in mirror.children {
            guard let name = name else { continue }
            stringToReturn += "\(name): \(value) \n"
        }
        
        return stringToReturn
    }
}
