//
//  JsonService.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 5/14/20.
//  Copyright © 2020 mSignia. All rights reserved.
//

import Foundation

class JsonService {
    
    // MARK: - Singleton
    static let shared = JsonService()
    
    // MARK: - Encoders
    func encode<T: Encodable>(_ object: T) -> (data: Data?, dictionary: [String: Any]?, error: Error?) {
        do {
            let paramsData = try JSONEncoder().encode(object)
            guard let paramsCast = try paramsData.jsonObject() as? [String: Any] else {
                let error = NSError(domain: "Json Encoding Error", code: -1, userInfo: [NSLocalizedDescriptionKey: "Could not encode object to json format"])
                return (nil, nil, error)
            }
            
            return (paramsData, paramsCast, nil)
        }
        catch {
            return (nil, nil, error)
        }
    }
    
    // MARK: - Decoders
    func decode<T: Decodable>(_ response: T.Type, from data: Data?) -> (response: T?, error: Error?) {
        guard let data = data else {
            let error = NSError(domain: "Json Decoding Error", code: -1, userInfo: [NSLocalizedDescriptionKey: "Could not decode json into object"])
            return (nil, error)
        }
        
        do {
            let decodedResponse = try JSONDecoder().decode(response, from: data)
            return (decodedResponse, nil)
        }
        catch {
            return (nil, error)
        }
    }
}
