//
//  LocationService.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 5/14/20.
//  Copyright © 2020 mSignia. All rights reserved.
//

import Foundation
import CoreLocation

protocol LocationServiceDelegate: class {
    func authorizationStatusDidChange(to status: CLAuthorizationStatus)
}

class LocationService: NSObject {
    
    // MARK: - Singleton
    static let shared = LocationService()
    
    // MARK: - Properties
    var delegate: LocationServiceDelegate?
    private var locationManager: CLLocationManager!
    
    // MARK: - Init
    override init() {
        locationManager = CLLocationManager()
    }
    
    // MARK: - Actions
    func requestPermission() {
        locationManager.delegate = self
        locationManager.requestWhenInUseAuthorization()
    }
}

// MARK: - CLLocationManagerDelegate methods
extension LocationService: CLLocationManagerDelegate {
    
    func locationManager(_ manager: CLLocationManager, didChangeAuthorization status: CLAuthorizationStatus) {
        locationManager.startUpdatingLocation()
        delegate?.authorizationStatusDidChange(to: status)
    }
}
